@@ -134,7 +134,6 @@ class DataSource:
 
         self.start_row = start_row
         self.end_row = end_row
-        self.separator = separator
         self.file_type = file_type
         self.num_files = num_files
         self.sample_separation = sample_separation
@@ -145,16 +144,23 @@ class DataSource:
         self.column_labels = column_labels if column_labels is not None else []
         self.figure_rcParams = figure_rcParams if figure_rcParams is not None else {}
 
+        # Turns the separator into a raw string equivalent so that it properly displays in the GUIs
+        if separator is not None:
+            for replacement in (('\\', '\\\\'), ('\n', '\\n'), ('\t', '\\t'), ('\r', '\\r')):
+                separator = separator.replace(*replacement)
+        self.separator = separator
+
         if unique_variables is None:
-            self.unique_variables = ['x', 'y']
+            self.unique_variables = []
         elif isinstance(unique_variables, str):
             self.unique_variables = [unique_variables]
         else:
             self.unique_variables = unique_variables
 
-        self.column_numbers = column_numbers if column_numbers is not None else [
-            *range(len(self.unique_variables))
-        ]
+        if column_numbers is not None:
+            self.column_numbers = column_numbers
+        else:
+            self.column_numbers = [*range(len(self.unique_variables))]
 
         # ensures the number of imported columns can accomodate all variables
         if len(self.column_numbers) < len(self.unique_variables):
@@ -189,7 +195,7 @@ class DataSource:
         # indices for each unique variable for data processing
         if unique_variable_indices is None:
             self.unique_variable_indices = [*range(len(self.unique_variables))]
-        elif isinstance(unique_variable_indices, str):
+        elif isinstance(unique_variable_indices, (str, int)):
             self.unique_variable_indices = [unique_variable_indices]
         else:
             self.unique_variable_indices = unique_variable_indices
